/*
******************************************************************************

   LibBLT: extension internals

   Copyright (C) 2001 Christoph Egger   [Christoph_Egger@t-online.de]

   Permission is hereby granted, free of charge, to any person obtaining a
   copy of this software and associated documentation files (the "Software"),
   to deal in the Software without restriction, including without limitation
   the rights to use, copy, modify, merge, publish, distribute, sublicense,
   and/or sell copies of the Software, and to permit persons to whom the
   Software is furnished to do so, subject to the following conditions:

   The above copyright notice and this permission notice shall be included in
   all copies or substantial portions of the Software.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
   THE AUTHOR(S) BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
   IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
   CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************************
*/

#ifndef _GGI_BLT_INT_H
#define _GGI_BLT_INT_H

#include <ggi/internal/internal.h>
#include <ggi/galloc.h>
#include <ggi/internal/galloc_ops.h>
#include <ggi/mmutil.h>

#define HAVE_STRUCT_BLT
#include <ggi/blt.h>

__BEGIN_DECLS

/* Exported variables */
#ifdef BUILDING_LIBBLT
extern ggi_extid    _bltID;
#else
IMPORTVAR ggi_extid _bltID;
#endif

__END_DECLS


struct ggiBlt {
	ggi_visual_t vis;

	batchop_t trans, sink;

	struct ggiGA_resource_props *req_carb_props;

	ggiGA_resource_handle *handles, def_carb_h;
	int numhandles;
};

struct ggiBlt_bob {
	ggi_pixel keyval, keymask;
	enum ggi_ll_rop rop;
	enum ggi_ll_math math;
	enum ggiBlt_bob_flags flags;
	ggiGA_resource_handle tank_h, carb_h;
	void *read, *write;
};
typedef struct ggiBlt_bob *ggiBlt_bob_t;

/* Data types for the API functions */
typedef ggiBlt_t (BltTie)(ggiGA_resource_handle *handles, int numhandles);
typedef int (BltUntie)(ggiBlt_t *blt);

typedef struct bltpriv {
	BltTie			*tie;
	BltUntie		*untie;

	ggiGA_resource_list *reqlist;  /* Pointer to application provided 
					  "global" request list for lazy API */

	void *priv;	/* Here sublibs can store visual specific private data.
			   If you have more than one sublib (for each visual)
			   that needs private data, just add more pointers or
			   add the data fields directly in this structure. */
} bltpriv;

/* Used to access the bltpriv structure for a particular visual. */
#define LIBGGI_BLTEXT(vis) ((bltpriv *)LIBGGI_EXT((vis),_bltID))

#endif /* _GGI_BLT_INT_H */
